pub struct ConfigBuilder { /* private fields */ }Implementations
Sourceimpl ConfigBuilder
impl ConfigBuilder
Sourcepub fn container_image(self, container_image: impl Into<String>) -> Self
pub fn container_image(self, container_image: impl Into<String>) -> Self
Set container image to use for schema command
Sourcepub fn container_wait(self, container_wait: u64) -> Self
pub fn container_wait(self, container_wait: u64) -> Self
Set container wait time in milliseconds after health check
Sourcepub fn name(self, name: impl Into<String>) -> Self
pub fn name(self, name: impl Into<String>) -> Self
Set just the package name, keeping other package defaults
Sourcepub fn destination(self, destination: impl Into<PathBuf>) -> Self
pub fn destination(self, destination: impl Into<PathBuf>) -> Self
Set destination folder for generated modules
Sourcepub fn generate_field_metadata(self, generate: bool) -> Self
pub fn generate_field_metadata(self, generate: bool) -> Self
Enable or disable generation of field metadata for queries
Sourcepub fn ignore_underscore_files(self, ignore_underscore_files: bool) -> Self
pub fn ignore_underscore_files(self, ignore_underscore_files: bool) -> Self
Ignore query files prefixed with underscore
Sourcepub fn params_only(self, params_only: bool) -> Self
pub fn params_only(self, params_only: bool) -> Self
Make bind functions private to force usage of params() method
Sourcepub fn package(self, package: Package) -> Self
pub fn package(self, package: Package) -> Self
Set package metadata for the generated Cargo.toml
Sourcepub fn add_static_file(self, file: StaticFile) -> Self
pub fn add_static_file(self, file: StaticFile) -> Self
Add a static file to copy
Sourcepub fn static_files(self, files: Vec<StaticFile>) -> Self
pub fn static_files(self, files: Vec<StaticFile>) -> Self
Set static files to copy
Sourcepub fn use_workspace_deps(self, use_workspace_deps: UseWorkspaceDeps) -> Self
pub fn use_workspace_deps(self, use_workspace_deps: UseWorkspaceDeps) -> Self
Configure workspace dependencies
Sourcepub fn add_type_mapping(
self,
key: impl Into<String>,
mapping: TypeMapping,
) -> Self
pub fn add_type_mapping( self, key: impl Into<String>, mapping: TypeMapping, ) -> Self
Add a type mapping
Sourcepub fn add_derive_trait(self, trait_name: impl Into<String>) -> Self
pub fn add_derive_trait(self, trait_name: impl Into<String>) -> Self
Add a derive trait for all generated structs/types
Sourcepub fn derive_traits(self, traits: Vec<impl Into<String>>) -> Self
pub fn derive_traits(self, traits: Vec<impl Into<String>>) -> Self
Set derive traits for all generated structs/types
Sourcepub fn add_type_trait_mapping(
self,
type_name: impl Into<String>,
traits: Vec<impl Into<String>>,
) -> Self
pub fn add_type_trait_mapping( self, type_name: impl Into<String>, traits: Vec<impl Into<String>>, ) -> Self
Add a type-specific trait mapping
Sourcepub fn add_dependency(
self,
name: impl Into<String>,
dependency: Dependency,
) -> Self
pub fn add_dependency( self, name: impl Into<String>, dependency: Dependency, ) -> Self
Add a dependency to the generated Cargo.toml