pub fn setup(
podman: bool,
container_image: &str,
container_wait: u64,
) -> Result<(), Error>Expand description
Starts Cornucopia’s database container and wait until it reports healthy.
Any existing cornucopia_postgres container is removed first to avoid
name conflicts left over from a previous failed run.