pub fn generate_managed(
    queries_path: &str,
    schema_files: Vec<String>,
    destination: Option<&str>,
    podman: bool,
    settings: CodegenSettings
) -> Result<String, Error>
Generates Rust queries from PostgreSQL queries located at queries_path, using a container managed by cornucopia. The database schema is created using schema_files. If some destination is given, the generated code will be written at that path. Code generation settings are set using the settings parameter.

By default, the container manager is Docker, but Podman can be used by setting the podman parameter to true.